==> pawm-1.9.7.tar.bz2: pawm-1.9.7/src/hints.c <==
/*
  Filename: hints.c  
  Synopsys: Hints module to read non ICCM hints
    
 	                      Copyright (C) 2001  
	         David Gmez Espinosa <david@pleyades.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include "hints.h"


/* This file is intended to put any function that is needed to read "standard"
 * hints like motif, gtk, etc.... ICCCM hints are supported in pawindow.c and
 * here are rest of the hints that may seem important. And for the moment that
 * is only one, for non-decorated windows. Non-ICCM hints suck, so this file
 * sucks too and shouldn't exists, but this is the wonderful world of X ;) */

Bool gtkHints_needDecoration(Window window) 
{
    Atom motif_hints;
    unsigned char *data;
    struct gtkHints *apphints;
    Atom rettype;
    int retformat;
    unsigned long nitems,nbytes;
    Bool rvalue;

    
    motif_hints=XInternAtom(display,"_MOTIF_WM_HINTS",True);
    if (motif_hints==None) return True;

    if (XGetWindowProperty(display,window,motif_hints,0L,20L,False,
			   motif_hints,&rettype,&retformat,
		           &nitems,&nbytes,&data)!=Success) BUG();

    apphints=(struct gtkHints *)(data);			   

    if (apphints) {
        if ( (apphints->flags & MWM_HINTS_DECORATIONS) &&
	    !(apphints->decorations & MWM_DECOR_ALL)) {

            rvalue=(apphints->decorations & MWM_DECOR_BORDER) ? True : False;   
	    XFree (apphints);
	     /* This window doesn't wants decoration */
	    return rvalue; 	
	}
    }

    return True;

}

==> pawm-2.2.2.tar.bz2: pawm-2.2.2/src/hints.c <==
/*
  Filename: hints.c  
  Synopsys: Hints module to read non ICCM hints
    
 	                      Copyright (C) 2001  
	         David Gmez Espinosa <david@pleyades.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include "hints.h"


/* This file is intended to put any function that is needed to read "standard"
 * hints like motif, gtk, etc.... ICCCM hints are supported in pawindow.c and
 * here are rest of the hints that may seem important. And for the moment that
 * is only one, for non-decorated windows. Non-ICCM hints suck, so this file
 * sucks too and shouldn't exists, but this is the wonderful world of X ;) */

Bool gtkHints_needDecoration(Window window) 
{
    Atom motif_hints;
    unsigned char *data;
    struct gtkHints *apphints;
    Atom rettype;
    int retformat;
    unsigned long nitems,nbytes;
    Bool rvalue;

    
    motif_hints=XInternAtom(display,"_MOTIF_WM_HINTS",True);
    if (motif_hints==None) return True;

    if (XGetWindowProperty(display,window,motif_hints,0L,20L,False,
			   motif_hints,&rettype,&retformat,
		           &nitems,&nbytes,&data)!=Success) return True;

    apphints=(struct gtkHints *)(data);			   

    if (apphints) {
        if ( (apphints->flags & MWM_HINTS_DECORATIONS) &&
	    !(apphints->decorations & MWM_DECOR_ALL)) {

            rvalue=(apphints->decorations & MWM_DECOR_BORDER) ? True : False;   
	    XFree (apphints);
	     /* This window doesn't wants decoration */
	    return rvalue; 	
	}
    }

    return True;

}
